@@ -9,4 +9,9 @@ class DataId(models.Model):
     
     
 class Data(orm.StdModel):
-    data = orm.ListField()
\ No newline at end of file
+    data = orm.ListField()
+    
+    
+class Environment(Data):
+    '''A derived model. To test for manager.'''
+    pass
\ No newline at end of file
